@@ -33,14 +33,28 @@ try:
     # https://github.com/ethereum/eth-abi/pull/88
     from eth_abi import abi
 
-    from autobahn.xbr._abi import XBR_TOKEN_ABI, XBR_NETWORK_ABI, XBR_CHANNEL_ABI  # noqa
-    from autobahn.xbr._abi import XBR_DEBUG_TOKEN_ADDR, XBR_DEBUG_NETWORK_ADDR  # noqa
+    from autobahn.xbr._abi import XBR_TOKEN_ABI, XBR_NETWORK_ABI, XBR_MARKET_ABI, XBR_CATALOG_ABI, XBR_CHANNEL_ABI  # noqa
+    from autobahn.xbr._abi import XBR_DEBUG_TOKEN_ADDR, XBR_DEBUG_NETWORK_ADDR, XBR_DEBUG_MARKET_ADDR, XBR_DEBUG_CATALOG_ADDR, XBR_DEBUG_CHANNEL_ADDR  # noqa
+    from autobahn.xbr._abi import XBR_DEBUG_TOKEN_ADDR_SRC, XBR_DEBUG_NETWORK_ADDR_SRC, XBR_DEBUG_MARKET_ADDR_SRC, XBR_DEBUG_CATALOG_ADDR_SRC, XBR_DEBUG_CHANNEL_ADDR_SRC  # noqa
     from autobahn.xbr._interfaces import IMarketMaker, IProvider, IConsumer, ISeller, IBuyer  # noqa
-    from autobahn.xbr._util import sign_eip712_data, recover_eip712_signer, pack_uint256, unpack_uint256  # noqa
+    from autobahn.xbr._util import make_w3, pack_uint256, unpack_uint256  # noqa
+
+    from autobahn.xbr._eip712_member_register import sign_eip712_member_register, recover_eip712_member_register  # noqa
+    from autobahn.xbr._eip712_member_login import sign_eip712_member_login, recover_eip712_member_login  # noqa
+    from autobahn.xbr._eip712_market_create import sign_eip712_market_create, recover_eip712_market_create  # noqa
+    from autobahn.xbr._eip712_market_join import sign_eip712_market_join, recover_eip712_market_join  # noqa
+    from autobahn.xbr._eip712_catalog_create import sign_eip712_catalog_create, recover_eip712_catalog_create  # noqa
+    from autobahn.xbr._eip712_api_publish import sign_eip712_api_publish, recover_eip712_api_publish  # noqa
+    from autobahn.xbr._eip712_consent import sign_eip712_consent, recover_eip712_consent  # noqa
+    from autobahn.xbr._eip712_channel_open import sign_eip712_channel_open, recover_eip712_channel_open  # noqa
+    from autobahn.xbr._eip712_channel_close import sign_eip712_channel_close, recover_eip712_channel_close  # noqa
+
     from autobahn.xbr._blockchain import SimpleBlockchain  # noqa
     from autobahn.xbr._seller import SimpleSeller, KeySeries  # noqa
     from autobahn.xbr._buyer import SimpleBuyer  # noqa
 
+    from autobahn.xbr._config import load_or_create_profile, UserConfig, Profile  # noqa
+
     HAS_XBR = True
 
     if not hasattr(abi, 'collapse_type'):
@@ -93,12 +107,27 @@ try:
 
     xbrtoken = None
     """
-    Contract instance of the token used in the XBR Network.
+    Contract instance of XBRToken.
     """
 
     xbrnetwork = None
     """
-    Contract instance of the XBR Network.
+    Contract instance of XBRNetwork.
+    """
+
+    xbrmarket = None
+    """
+    Contract instance of XBRMarket.
+    """
+
+    xbrcatalog = None
+    """
+    Contract instance of XBRMarket.
+    """
+
+    xbrchannel = None
+    """
+    Contract instance of XBRMarket.
     """
 
     def setProvider(_w3):
@@ -108,6 +137,9 @@ try:
         """
         global xbrtoken
         global xbrnetwork
+        global xbrmarket
+        global xbrcatalog
+        global xbrchannel
 
         # print('Provider set - xbrtoken={}'.format(XBR_DEBUG_TOKEN_ADDR))
         xbrtoken = _w3.eth.contract(address=XBR_DEBUG_TOKEN_ADDR, abi=XBR_TOKEN_ABI)
@@ -115,6 +147,15 @@ try:
         # print('Provider set - xbrnetwork={}'.format(XBR_DEBUG_NETWORK_ADDR))
         xbrnetwork = _w3.eth.contract(address=XBR_DEBUG_NETWORK_ADDR, abi=XBR_NETWORK_ABI)
 
+        # print('Provider set - xbrmarket={}'.format(XBR_DEBUG_MARKET_ADDR))
+        xbrmarket = _w3.eth.contract(address=XBR_DEBUG_MARKET_ADDR, abi=XBR_MARKET_ABI)
+
+        # print('Provider set - xbrcatalog={}'.format(XBR_DEBUG_CATALOG_ADDR))
+        xbrcatalog = _w3.eth.contract(address=XBR_DEBUG_CATALOG_ADDR, abi=XBR_CATALOG_ABI)
+
+        # print('Provider set - xbrchannel={}'.format(XBR_DEBUG_CHANNEL_ADDR))
+        xbrchannel = _w3.eth.contract(address=XBR_DEBUG_CHANNEL_ADDR, abi=XBR_CHANNEL_ABI)
+
     class MemberLevel(object):
         """
         XBR Network member levels.
@@ -135,15 +176,50 @@ try:
         CORE = 2
         EDGE = 3
 
+    class ChannelType(object):
+        """
+        Type of a XBR off-chain channel: paying channel (for provider delegates selling data services) or payment channel (for consumer delegates buying data services).
+        """
+
+        NONE = 0
+        """
+        Unset
+        """
+
+        PAYMENT = 1
+        """
+        Payment channel: from buyer/consumer delegate to maker maker.
+        """
+
+        PAYING = 2
+        """
+        Paying channel: from market maker to seller/provider delegate.
+        """
+
     class ActorType(object):
         """
-        XBR Market actor types.
+        XBR Market Actor type.
         """
+
         NONE = 0
-        NETWORK = 1
-        MARKET = 2
-        PROVIDER = 3
-        CONSUMER = 4
+        """
+        Unset
+        """
+
+        PROVIDER = 1
+        """
+        Actor is a XBR Provider.
+        """
+
+        CONSUMER = 2
+        """
+        Actor is a XBR Consumer.
+        """
+
+        PROVIDER_CONSUMER = 3
+        """
+        Actor is both a XBR Provider and XBR Consumer.
+        """
 
     def generate_seedphrase(strength=128, language='english'):
         """
@@ -182,33 +258,59 @@ try:
 
     __all__ = (
         'HAS_XBR',
-        'setProvider',
-
+        'XBR_TOKEN_ABI',
+        'XBR_NETWORK_ABI',
+        'XBR_MARKET_ABI',
+        'XBR_CATALOG_ABI',
+        'XBR_CHANNEL_ABI',
         'xbrtoken',
         'xbrnetwork',
-        'sign_eip712_data',
-        'recover_eip712_signer',
+        'xbrmarket',
+        'xbrcatalog',
+        'xbrchannel',
+
+        'setProvider',
+        'make_w3',
         'pack_uint256',
         'unpack_uint256',
+        'generate_seedphrase',
+        'check_seedphrase',
+        'account_from_seedphrase',
+        'ASCII_BOMB',
+
+        'sign_eip712_member_register',
+        'recover_eip712_member_register',
+        'sign_eip712_member_login',
+        'recover_eip712_member_login',
+        'sign_eip712_market_create',
+        'recover_eip712_market_create',
+        'sign_eip712_market_join',
+        'recover_eip712_market_join',
+        'sign_eip712_catalog_create',
+        'recover_eip712_catalog_create',
+        'sign_eip712_api_publish',
+        'recover_eip712_api_publish',
+        'sign_eip712_consent',
+        'recover_eip712_consent',
+        'sign_eip712_channel_open',
+        'recover_eip712_channel_open',
+        'sign_eip712_channel_close',
+        'recover_eip712_channel_close',
+
+        'load_or_create_profile',
+        'UserConfig',
+        'Profile',
+
+        'MemberLevel',
+        'ActorType',
+        'ChannelType',
+        'NodeType',
 
         'KeySeries',
         'SimpleBlockchain',
         'SimpleSeller',
         'SimpleBuyer',
 
-        'generate_seedphrase',
-        'check_seedphrase',
-        'account_from_seedphrase',
-
-        'MemberLevel',
-        'ActorType',
-        'NodeType',
-
-        'XBR_TOKEN_ABI',
-        'XBR_NETWORK_ABI',
-        'XBR_CHANNEL_ABI',
-        'ASCII_BOMB',
-
         'IMarketMaker',
         'IProvider',
         'IConsumer',
@@ -216,6 +318,9 @@ try:
         'IBuyer',
     )
 
-except ImportError:
+except (ImportError, FileNotFoundError) as e:
+    import sys
+    sys.stderr.write(str(e))
+    sys.stderr.flush()
     HAS_XBR = False
     __all__ = ('HAS_XBR',)
